BoardController class
Constructors
- BoardController({BoardState? initialState, bool confirmBeforeDelete = false, BoardStyle style = const BoardStyle(), OnEdgeCreated? onEdgeCreated})
Properties
- confirmBeforeDelete → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
nodeRenderRegistry
→ Map<
String, NodeWidgetBuilder> -
final
- onEdgeCreated → OnEdgeCreated?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
state
→ ValueNotifier<
BoardState> -
final
-
stream
→ Stream<
(EventData, EventType)> -
no setter
-
streamController
→ StreamController<
(EventData, EventType)> -
final
- style → BoardStyle
-
final
- value ↔ BoardState
-
getter/setter pair
Methods
-
changeEditableStatus(
bool editable) → dynamic -
clear(
) → void -
dispose(
) → void -
dumpToString(
) → String -
getExtraNodeConfig(
String nodeType) → ExtraNodeConfig -
getNodeData(
String uuid) → NodeModel? -
getPath(
NodeModel node) → List< List< String> > -
moveToOffset(
Offset offset) → dynamic - move board to offset
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reCenter(
) → void -
reCreate(
List< NodeModel> nodes, List<Edge> edges) → void -
removeEdge(
Edge edge) → dynamic -
setConfig(
String nodeType, ExtraNodeConfig config) → void -
setCurrentFocus(
NodeModel? node) → dynamic -
setEdgeFocused(
Edge edge) → dynamic -
setSize(
Size size) → void -
toString(
) → String -
A string representation of this object.
inherited
-
updateNode(
NodeModel node) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited