BoardStyle class

Constructors

BoardStyle({double sidebarMaxWidth = 240, double sidebarMinWidth = 30, double sidebarMaxHeight = 600, double sidebarMinHeight = 30})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sidebarMaxHeight double
final
sidebarMaxWidth double
final
sidebarMinHeight double
final
sidebarMinWidth double
final

Methods

copyWith({double? sidebarMaxWidth, double? sidebarMinWidth, double? sidebarMaxHeight, double? sidebarMinHeight}) BoardStyle
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited