Edge class

Constructors

Edge({required String uuid, required String source, String? target, required Offset start, required Offset end})
Edge.fromJson(Map<String, dynamic> json)
factory

Properties

end Offset
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source String
final
start Offset
final
target String?
final
uuid String
final

Methods

copyWith({String? uuid, String? source, String? target, Offset? start, Offset? end}) Edge
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override