BoardState class
Constructors
Properties
-
data
→ List<
NodeModel> -
final
- dragOffset → Offset
-
final
- edgeFocused ↔ Edge?
-
getter/setter pair
-
edges
→ Set<
Edge> -
final
- editable → bool
-
final
- focused ↔ String?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- paintSize ↔ Size?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scaleFactor → double
-
final
Methods
-
copyWith(
{double? scaleFactor, Offset? dragOffset, List< NodeModel> ? data, Set<Edge> ? edges, String? focused, Edge? edgeFocused, Size? paintSize, bool? editable}) → BoardState -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited