NodeModel class
Constructors
-
NodeModel({required String uuid, required String type, required String label, required Offset offset, double width = 125, double height = 60, String? description, Map<
String, dynamic> data = const {}, Map<String, Map< ? prevData})String, dynamic> ?> -
NodeModel.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
data
↔ Map<
String, dynamic> -
getter/setter pair
- description → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double
-
final
- inputPoint → Offset
-
no setter
- label → String
-
final
- offset → Offset
-
final
- onStatusChanged ↔ OnNodeStatusChanged?
-
getter/setter pair
- outputPoint → Offset
-
no setter
-
prevData
↔ Map<
String, Map< ?String, dynamic> ?> -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String
-
final
- uuid → String
-
final
- width → double
-
final
Methods
-
copyWith(
{String? uuid, String? type, String? label, Offset? offset, double? width, double? height, Map< String, dynamic> ? data, Map<String, Map< ? prevData, String? description}) → NodeModelString, dynamic> > -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited